==> kwy-login-1.0-425059.tar: src/service/UserLogin.php <==
<?php
/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 2019/9/6
 * Time: 14:41
 */

namespace kwy\login\service;


use kwy\login\exception\PasswordErrorException;
use kwy\login\exception\UnLoginException;
use kwy\login\model\CompanyHasShop;
use kwy\login\model\KwyUser;
use kwy\login\model\Shop;
use kwy\login\model\ShopToken;
use Lcobucci\JWT\Builder;
use Lcobucci\JWT\Parser;
use Lcobucci\JWT\Signer\Hmac\Sha256;
use think\facade\Config;
use think\facade\Log;

class UserLogin
{
    private $user;

    private $shop;

    private $company;

    public function login($tel,$password){
        $kwy_user = KwyUser::where('tel','=',$tel)->find();
        if(!$kwy_user){
            throw new \Exception("登录用户不存在");
        }
        if(strcmp($password,$kwy_user['password'])){
            throw new PasswordErrorException("密码错误");
        }
        if($kwy_user['status'] == '禁用'){
            throw new \Exception("用户被禁用");
        }
        $company_data = Company::where('kwy_user_id','=',$kwy_user['id'])->find();
        if(!$company_data){
            throw new \Exception("企业数据缺失");
        }
        $company = [
            'id' => $company_data['id'],
            'name' => $company_data['name'],
            'short_name' => $company_data['short_name'],
            'shop_id' => $company_data['shop_id'],
            'kwy_industry_id' => $company_data['kwy_industry_id'],
        ];
        $shop_data = Shop::where('id','=',$company_data['shop_id'])->find();
        if($shop_data['status'] == '0'){
            throw new \Exception("店铺被禁用");
        }
        $shop = [
            'id' => $shop_data['id'],
            'name' => $shop_data['company_name'],
            'industry_id' => $shop_data['industry_id'],
        ];

        $user = [
            'id' => $kwy_user['id'],
            'name' => $kwy_user['name'],
            'tel' => $kwy_user['tel'],
            'remark' => $kwy_user['remark'],
        ];

        #jwt设置
        $signer = new Sha256();
        $token = (new Builder())->setIssuer('kwy_user_token')
            ->setIssuedAt(time())
            ->set('user',json_encode($user))
            ->set('company',json_encode($company))
            ->set('shop',json_encode($shop))
            ->set('time_key',time())
            ->sign($signer,Config::get('jwt.kwy_user','hgfhfwetsfdsdklmd124fdsfmk35'))
            ->getToken();
        $token_string = $token->__toString();
        session('user_sign', $token_string);
        session('user',$user);
        cache('session:'.$token->__toString(),$token->__toString(),7*24*3600);
        #存入表，方便切换店铺
        $shop_token_find = ShopToken::where('shop_id','=',$shop['id'])->find();
        if($shop_token_find){
            ShopToken::where('shop_id','=',$shop['id'])->update(['token'=>$token_string]);
        }
        return $token_string;
    }

    public function getKwyUser(string $token=''){
        if (empty($this->user)){
            if (empty($token)){
                $token=session('user_sign');
                if (empty($token)){
                    $token=request()->server('http_token');
                }
            }
            try{
                $jwt = (new Parser())->parse($token);
                if(!$jwt->verify(new Sha256(),Config::get('jwt.kwy_user','hgfhfwetsfdsdklmd124fdsfmk35'))){
                    throw new UnLoginException('用户未登录');
                }
                $userinfo_json = $jwt->getClaim('user');
                $userinfo = json_decode($userinfo_json,true);
            }catch (\Exception $e){
                Log::log('error',$e->getMessage().'|jwt_token='.$token.'|session='.session('user_sign'));
                throw new UnLoginException('用户未登录');
            }
            $this->user=$userinfo;
        }
        return $this->user;
    }

    public function getShop(string $token=''){
        if (empty($this->shop)){
            if (empty($token)){
                $token=session('user_sign');
                if (empty($token)){
                    $token=request()->server('http_token');
                }
            }
            try{
                $jwt = (new Parser())->parse($token);
                if(!$jwt->verify(new Sha256(),Config::get('jwt.kwy_user','hgfhfwetsfdsdklmd124fdsfmk35'))){
                    throw new UnLoginException('用户未登录');
                }
                $shop_json = $jwt->getClaim('shop');
                $shopinfo = json_decode($shop_json,true);
            }catch (\Exception $e){
                Log::log('error',$e->getMessage().'|jwt_token='.$token.'|session='.session('user_sign'));
                throw new UnLoginException('用户未登录');
            }
            $this->shop=$shopinfo;
        }
        return $this->shop;
    }

    public function getCompany(string $token=''){
        if (empty($this->user)){
            if (empty($token)){
                $token=session('user_sign');
                if (empty($token)){
                    $token=request()->server('http_token');
                }
            }
            try{
                $jwt = (new Parser())->parse($token);
                if(!$jwt->verify(new Sha256(),config('jwt.kwy_user','hgfhfwetsfdsdklmd124fdsfmk35'))){
                    throw new UnLoginException('用户未登录');
                }
                $companyinfo_json = $jwt->getClaim('company');
                $companyinfo = json_decode($companyinfo_json,true);
            }catch (\Exception $e){
                Log::log('error',$e->getMessage().'|jwt_token='.$token.'|session='.session('user_sign'));
                throw new UnLoginException('用户未登录');
            }
            $this->company=$companyinfo;
        }
        return $this->company;
    }

    //切换店铺
    public function changeShop($shop_id,string $token=''){
        $company = $this->getCompany($token);
        $find = CompanyHasShop::where('company_id','=',$company['id'])->where('shop_id','=',$shop_id)->find();
        if(empty($find)){
            throw new \Exception("没有登录该店铺权限");
        }
        $user = $this->getKwyUser();

        $shop_data = Shop::where('id','=',$shop_id)->find();
        if($shop_data['status'] == '0'){
            throw new \Exception("店铺被禁用");
        }
        $shop = [
            'id' => $shop_data['id'],
            'name' => $shop_data['company_name'],
            'industry_id' => $shop_data['industry_id'],
        ];

        #jwt设置
        $signer = new Sha256();
        $token = (new Builder())->setIssuer('kwy_user_token')
            ->setIssuedAt(time())
            ->set('user',json_encode($user))
            ->set('company',json_encode($company))
            ->set('shop',json_encode($shop))
            ->set('time_key',time())
            ->sign($signer,Config::get('jwt.kwy_user','hgfhfwetsfdsdklmd124fdsfmk35'))
            ->getToken();
        $token_string = $token->__toString();
        session('user_sign', $token_string);
        session('user',$user);
        cache('session:'.$token->__toString(),$token->__toString(),7*24*3600);
        #存入表，方便切换店铺
        $shop_token_find = ShopToken::where('shop_id','=',$shop['id'])->find();
        if($shop_token_find){
            ShopToken::where('shop_id','=',$shop['id'])->update(['token'=>$token_string]);
        }
        return $token_string;
    }

}

==> kwy-login-1.7.2-792058.tar: src/service/UserLogin.php <==
<?php
/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 2019/9/6
 * Time: 14:41
 */

namespace kwy\login\service;


use kwy\login\exception\PasswordErrorException;
use kwy\login\exception\UnLoginException;
use kwy\login\model\Company;
use kwy\login\model\CompanyHasShop;
use kwy\login\model\JwtCompany;
use kwy\login\model\KwyUser;
use kwy\login\model\Shop;
use kwy\login\model\ShopToken;
use Lcobucci\JWT\Builder;
use Lcobucci\JWT\Parser;
use Lcobucci\JWT\Signer\Hmac\Sha256;
use think\facade\Config;
use think\facade\Log;

class UserLogin
{
    private $user;

    private $shop;

    private $company;

    public function login($tel,$password){
        $kwy_user = KwyUser::where('tel','=',$tel)->find();
        if(!$kwy_user){
            throw new \Exception("登录用户不存在");
        }
        if(strcmp($password,$kwy_user['password'])){
            throw new PasswordErrorException("密码错误");
        }
        if($kwy_user['status'] == '禁用'){
            throw new \Exception("用户被禁用");
        }
        $company_data = Company::where('kwy_user_id','=',$kwy_user['id'])->find();
        if(!$company_data){
            throw new \Exception("企业数据缺失");
        }
        $company = [
            'id' => $company_data['id'],
            'name' => $company_data['name'],
            'short_name' => $company_data['short_name'],
            'shop_id' => $company_data['shop_id'],
            'kwy_industry_id' => $company_data['kwy_industry_id'],
        ];
        $shop_data = Shop::where('id','=',$company_data['shop_id'])->find();
        if($shop_data['status'] == '0'){
            throw new \Exception("店铺被禁用");
        }
        $shop = [
            'id' => $shop_data['id'],
            'name' => $shop_data['company_name'],
            'logo' => $shop_data['shoplogo_url'],
            'industry_id' => $shop_data['industry_id'],
        ];

        $user = [
            'id' => $kwy_user['id'],
            'name' => $kwy_user['name'],
            'tel' => $kwy_user['tel'],
            'remark' => $kwy_user['remark'],
            'is_company_staff' => false,
        ];

        #jwt设置
        $signer = new Sha256();
        $token = (new Builder())->setIssuer('kwy_user_token')
            ->setIssuedAt(time())
            ->set('user',json_encode($user))
            ->set('company',json_encode($company))
            ->set('shop',json_encode($shop))
            ->set('time_key',time())
            ->sign($signer,Config::get('jwt.kwy_login','hgfhfwetsfdsdklmd124fdsfmk35'))
            ->getToken();
        $token_string = $token->__toString();
        #存入表，方便切换店铺
        $shop_token_find = ShopToken::get($shop['id']);
        if($shop_token_find){
            model(ShopToken::class)->where('shop_id','=',$shop['id'])->update(['token'=>$token_string]);
        }else{
            model(ShopToken::class)->insert(['shop_id'=>$shop['id'],'token'=>$token_string]);
        }
        return $token_string;
    }

    /**
     * @param string $token
     * @return mixed
     * @throws UnLoginException
     */
    public function getKwyUser(string $token=''){
        if (empty($this->user)){
            if (empty($token)){
                $token=request()->server('http_token');
            }
            try{
                $jwt = (new Parser())->parse($token);
                if(!$jwt->verify(new Sha256(),Config::get('jwt.kwy_login','hgfhfwetsfdsdklmd124fdsfmk35'))){
                    throw new UnLoginException('用户未登录');
                }
                $old_time = $jwt->getClaim('time_key');
                $expire = intval(time()-$old_time);
                if($expire > 7*24*3600){
                    throw new UnLoginException("登录已过期，请重新登录");
                }
                $userinfo_json = $jwt->getClaim('user');
                $userinfo = json_decode($userinfo_json);
            }catch (\Exception $e){
                Log::log('error',$e->getMessage().'|jwt_token='.$token.'|session='.session('user_sign'));
                throw new UnLoginException('用户未登录');
            }
            $this->user=$userinfo;
        }
        return $this->user;
    }

    public function getShop(string $token=''){
        if (empty($this->shop)){
            if (empty($token)){
                $token=request()->server('http_token');
            }
            try{
                $jwt = (new Parser())->parse($token);
                if(!$jwt->verify(new Sha256(),Config::get('jwt.kwy_login','hgfhfwetsfdsdklmd124fdsfmk35'))){
                    throw new UnLoginException('用户未登录');
                }
                $old_time = $jwt->getClaim('time_key');
                $expire = intval(time()-$old_time);
                if($expire > 7*24*3600){
                    throw new UnLoginException("登录已过期，请重新登录");
                }
                $shop_json = $jwt->getClaim('shop');
                $shopinfo = json_decode($shop_json);
            }catch (\Exception $e){
                Log::log('error',$e->getMessage().'|jwt_token='.$token.'|session='.session('user_sign'));
                throw new UnLoginException('用户未登录');
            }
            $this->shop=$shopinfo;
        }
        return $this->shop;
    }

    /**
     * @param string $token
     * @return JwtCompany
     * @throws UnLoginException
     */
    public function getCompany(string $token=''){
        if (empty($this->company)){
            if (empty($token)){
                $token=request()->server('http_token');
            }
            try{
                $jwt = (new Parser())->parse($token);
                if(!$jwt->verify(new Sha256(),config('jwt.kwy_login','hgfhfwetsfdsdklmd124fdsfmk35'))){
                    throw new UnLoginException('用户未登录');
                }
                $old_time = $jwt->getClaim('time_key');
                $expire = intval(time()-$old_time);
                if($expire > 7*24*3600){
                    throw new UnLoginException("登录已过期，请重新登录");
                }
                $companyinfo_json = $jwt->getClaim('company');
                $companyinfo = json_decode($companyinfo_json);
            }catch (\Exception $e){
                Log::log('error',$e->getMessage().'|jwt_token='.$token.'|session='.session('user_sign'));
                throw new UnLoginException('用户未登录');
            }
            $this->company=$companyinfo;
        }
        return $this->company;
    }

    //切换店铺
    public function changeShop($shop_id,string $token=''){
        $company = $this->getCompany($token);
        $find = CompanyHasShop::where('company_id','=',$company->id)->where('shop_id','=',$shop_id)->find();
        if(empty($find)){
            throw new \Exception("没有登录该店铺权限");
        }
        $user = $this->getKwyUser();

        $shop_data = Shop::where('id','=',$shop_id)->find();
        if($shop_data['status'] == '0'){
            throw new \Exception("店铺被禁用");
        }
        $shop = [
            'id' => $shop_data['id'],
            'name' => $shop_data['company_name'],
            'industry_id' => $shop_data['industry_id'],
        ];

        #jwt设置
        $signer = new Sha256();
        $token = (new Builder())->setIssuer('kwy_user_token')
            ->setIssuedAt(time())
            ->set('user',json_encode($user))
            ->set('company',json_encode($company))
            ->set('shop',json_encode($shop))
            ->set('time_key',time())
            ->sign($signer,Config::get('jwt.kwy_login','hgfhfwetsfdsdklmd124fdsfmk35'))
            ->getToken();
        $token_string = $token->__toString();
        #存入表，方便切换店铺
        $shop_token_find = ShopToken::get($shop_id);
        if($shop_token_find){
            model(ShopToken::class)->where('shop_id','=',$shop_id)->update(['token'=>$token_string]);
        }else{
            model(ShopToken::class)->insert(['shop_id'=>$shop_id,'token'=>$token_string]);
        }
        return $token_string;
    }

}
